/*
 *    **************************************************
 *    *                                                *
 *    *                   BIGCALC.H                    *
 *    *                                                *
 *    *          Extended Precision Calculator         *
 *    *                                                *
 *    *     Global Constants & Function Prototypes     *
 *    *                                                *
 *    *              Version 2.11 03-27-88             *
 *    *                                                *
 *    *              Judson D. McClendon               *
 *    *              844 Sun Valley Road               *
 *    *              Birmingham, AL 35215              *
 *    *                 205-853-8440                   *
 *    *            Compuserve [74415,1003]             *
 *    *                                                *
 *    **************************************************
 */



/*
 *    **************************************************
 *    *                                                *
 *    *                   Constants                    *
 *    *                                                *
 *    **************************************************
 */

#define TITLE "Extended Precision Calculator 2.11"

#define MINPREC 3                   /* Min nbr of digits  */
#define DEFAULTPREC 100             /* Default precision  */
#define NORMPREC 1020               /* Max nbr of digits  */
#define COMPPREC (NORMPREC + 5)     /* Compute precision  */
#define WORKPREC (COMPPREC * 2 + 5) /* Max Work precision */
#define MAXEXDIGITS 5               /* Max exponent digits */
#define MINEXP -99999L              /* Min exponent */
#define MAXEXP  99999L              /* Max exponent */
#define MINFLOATDSP -50L            /* Min exp floating decimal display */
#define MAXFLOATDSP 68L             /* Max exp floating decimal display */
#define XSIGNROW 18                 /* X sign row */
#define ENTRYSIGNROWBIG 4           /* Sign row for big X */
#define ENTRYSIGNROWSMALL 18        /* Sign row for small X */
#define SIZEOFSMALL 488             /* Max size for part screen entry */
#define SIGNDISPCOL 3               /* Sign column for number display */
#define MINDISPCOL 4                /* Min column for number display */
#define MAXDISPCOL 73               /* Max column for number display */
#define SIGNPRTCOL 4                /* Sign column for number printer */
#define MINPRTCOL 5                 /* Min column for number printer */
#define MAXPRTCOL 63                /* Max column for number printer */
#define DISPDECIMAL '.'             /* Display decimal point */
#define PRINTDECIMAL '*'            /* Print decimal point */



/*
 *    **************************************************
 *    *                                                *
 *    *                    Defines                     *
 *    *                                                *
 *    **************************************************
 */

#ifndef TRUE
#define TRUE 1
#endif

#ifndef FALSE
#define FALSE 0
#endif

#ifndef BOOLEAN
#define BOOLEAN int
#endif




/*
 *    **************************************************
 *    *                                                *
 *    *                   Key Codes                    *
 *    *                                                *
 *    **************************************************
 */

#define ESCAPE     27   /* Escape          */
#define BACKSPACE  8    /* Back Space      */
#define CR         '\r' /* Carriage Return */
#define LF         '\n' /* Line Feed       */
#define FF         '\f' /* Form Feed       */

#define ADD        43   /*  +          */
#define SUBTRACT   45   /*  -          */
#define MULTIPLY   42   /*  *          */
#define DIVIDE     47   /*  /          */
#define LASTX      76   /*  L          */
#define CLEAR      67   /*  C          */
#define PRINT      80   /*  P          */
#define SCINOT     70   /*  F          */
#define XCHGXREG   88   /*  X          */
#define CHGSIGN    83   /*  S          */
#define PRINTDISK  68   /*  D          */
#define GROUPSIZE  71   /*  G          */
#define VIEWREG    86   /*  V          */
#define CLEARX     8    /* Back Space  */
#define STOREX     1073 /* PgUp        */
#define RECALLREG  1081 /* PgDn        */
#define ENTER      13   /* Enter       */
#define XCHGXY1    1075 /* Left Arrow  */
#define XCHGXY2    1077 /* Right Arrow */
#define ROLLDOWN   1080 /* Down Arrow  */
#define ROLLUP     1072 /* Up Arrow    */
#define HELP       1059 /* F1          */
#define ABS        1060 /* F2          */
#define SQUAREROOT 1061 /* F3          */
#define SQUARE     1062 /* F4          */
#define RECIPROCAL 1063 /* F5          */
#define FACTORIAL  1064 /* F6          */
#define INTEGER    1065 /* F7          */
#define FRACTION   1066 /* F8          */
#define RECALLPI   1067 /* F9          */
#define RECALLE    1068 /* F10         */



/*
 *    **************************************************
 *    *                                                *
 *    *                  Data Types                    *
 *    *                                                *
 *    **************************************************
 */

typedef char NORMDIGIT;
typedef int  WORKDIGIT;

typedef struct {
   long exp;
   int sign;
   int digits;
   NORMDIGIT man[NORMPREC];
   } NORMTYPE;

typedef struct {
   long exp;
   int sign;
   int digits;
   WORKDIGIT man[WORKPREC];
   } WORKTYPE;



/*
 *    **************************************************
 *    *                                                *
 *    *        BIGCALC.C Function Declarations         *
 *    *                                                *
 *    **************************************************
 */

void main(int argc,char * *argv);
void Initialize(int argc,char *argv);

void Add(void);
void Subtract(void);
void Multiply(void);
void Divide(void);
void AbsoluteValue(void);
void SquareRoot(void);
void Square(void);
void Reciprocal(void);
void Factorial(void);
void IntegerPart(void);
void FractionPart(void);
void RecallPi(void);
void RecallE(void);
void RecallLastX(void);
void ChangeSign(void);
void PrintDisk(void);
void GroupSize(void);
void ViewReg(void);
void AcceptX(void);
void ClearX(void);
void Enter(void);
void SciNotation(void);
void Clear(void);
void Print(void);
void StoreX(void);
void AddXReg(void);
void SubtractXReg(void);
void MultiplyXReg(void);
void DivideXReg(void);
void RecallReg(void);
void AddRegX(void);
void SubtractRegX(void);
void MultiplyRegX(void);
void DivideRegX(void);
void ExchangeXY(void);
void ExchangeXReg(void);
void RollDown(void);
void RollUp(void);
void PushStack(void);
void DropStack(void);



/*
 *    **************************************************
 *    *                                                *
 *    *         BIGIO.C Function Declarations          *
 *    *                                                *
 *    **************************************************
 */

int  GetChar(void);
int  KeyPressed(void);

void ScrClr(void);
void EraEol(void);
void EraEop(void);
void CurPos(int row,int col);
void CurGet(int *row,int *col);
void WNChar(int chr,int count);
void WChar(int chr);
void WString(char *str);
void WInteger(long integer);
void WriteAt(int row,int col,char *str);
void WriteCenter(int row,char *msg);
void Message(char *msg);
void MessageWait(char *msg);
void MessageEsc(char *msg);

void DisplayChar(int *row,int *col,int chr);
void BackSpace(int *row,int *col);
void DisplayExpChar(int *row,int *col,int chr);
void BackSpaceExp(int *row,int *col);
void DisplayExp(int *row,int *col,int exprow,int expcol,int expsign,long exponent);

void PChar(int chr);
void PString(char *str);
void PInteger(long integer);
void NewLine(void);
void NewPage(void);

void Beep(void);
long TimerTicks(void);



/*
 *    **************************************************
 *    *                                                *
 *    *        BIGMATH.C Function Declarations         *
 *    *                                                *
 *    **************************************************
 */

int  ExtendedGetX(void);
int  ExtendedAdd(void);
int  ExtendedSubtract(void);
int  ExtendedMultiply(void);
int  ExtendedDivide(void);
int  ExtendedSquareRoot(void);
int  ExtendedReciprocal(void);
int  ExtendedFactorial(void);
int  ExtendedIntegerPart(void);
int  ExtendedFractionPart(void);
int  Normalize(int w);

void ExtendedRecallPi(void);
void ExtendedRecallE(void);
void ClearStack(int lo,int hi);
void ClearReg(int lo,int hi);
void ClearWork(int lo,int hi);
void FlipSign(int *sign);

void MoveRegWork(int source,int dest);
void MoveStackWork(int source,int dest);
void MoveWorkReg(int source,int dest);
void MoveWorkStack(int source,int dest);



/*
 *    **************************************************
 *    *                                                *
 *    *       BIGPRINT.C Function Declarations         *
 *    *                                                *
 *    **************************************************
 */

void PrintReg(int lo,int hi);
void PrintStack(int lo,int hi);
void DisplayReg(int r);
void DisplayStack(int s);
void PrintNumber(NORMTYPE *nbr);
void PCharWrap(int chr);
void PSign(int sign);
void PExponent(long exponent);

void WriteReg(int lo,int hi);
void WriteStack(int lo,int hi);
void WriteNumber(NORMTYPE *nbr);
void WExponent(long exponent);
int  GetPrompt(void);
void Overflow(void);
void DivideByZero(void);
void NegativeArgument(void);
void ArgumentNotInteger(void);

void OnScreenMenu(void);
void InitialScreen(void);
void HelpScreen(void);
void Heading1(void);
void Heading2(void);
void HelpScreen1(void);
void HelpScreen2(void);
void HelpScreen3(void);
void WorkScreen(void);
